@@ -1,75 +1,35 @@
 package XAS::Base;
 
 our $MESSAGES;
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 our $EXCEPTION = 'XAS::Exception';
-our ($SCRIPT)  = ( $0 =~ m#([^\\/]+)$# );
 
 use XAS::Factory;
 use XAS::Exception;
-use Config::IniFiles;
 use Params::Validate ':all';
 
 use XAS::Class
   debug      => 0,
   version    => $VERSION,
   base       => 'Badger::Base',
-  utils      => 'dotid dir_walk',
+  utils      => 'dotid',
   auto_can   => '_auto_load',
+  accessors  => 'env',
   filesystem => 'Dir',
   vars => {
     PARAMS => {
-      -xdebug => { optional => 1, default => 0 }
-    }
+      -alerts => { optional => 1, default => 0 },
+      -xdebug => { optional => 1, default => 0 },
+    },
   }
 ;
 
-#use Data::Dumper;
+use Data::Dumper;
 
 # ----------------------------------------------------------------------
 # Public Methods
 # ----------------------------------------------------------------------
 
-sub load_msgs {
-    my $self = shift;
-
-    my $messages = $self->class->any_var('MESSAGES');
-    return if (defined($messages->{messages_loaded});
-
-    foreach my $path (@INC) {
-
-        my $dir = Dir($path, 'XAS');
-
-        if ($dir->exists) {
-
-            dir_walk(
-                -directory => $dir, 
-                -filter    => $self->env->msgs, 
-                -callback  => sub {
-                    my $file = shift;
-
-                    my $cfg = Config::IniFiles->new(-file => $file->path);
-                    if (my @names = $cfg->Parameters('messages')) {
-                        
-                        foreach my $name (@names) {
-                            
-                            $messages->{$name} = $cfg->val('messages', $name);
-
-                        }
-
-                    }
-
-                }
-            );
-
-        }
-
-    }
-
-    $MESSAGES = $messages;
-
-}
-
 sub validation_exception {
     my $param = shift;
     my $class = shift;
@@ -126,18 +86,6 @@ sub _auto_load {
 
     }
 
-    if ($name eq 'alerts') {
-
-        return sub { XAS::Alerts->new(); } 
-
-    }
-
-    if ($name eq 'env') {
-
-        return sub { XAS::Factory->module('environment'); } 
-
-    }
-
     if ($name eq 'email') {
 
         return sub { XAS::Factory->module('email'); } 
@@ -149,10 +97,11 @@ sub _auto_load {
         return sub { 
 
             XAS::Factory->module('logger', {
-                -type     => $self->env->logtype,
+                -type     => $self->env->log_type,
                 -filename => $self->env->logfile,
+                -process  => $self->env->script,
                 -levels => {
-                    debug => $self->debugging ? 1 : 0,
+                    debug => $self->env->xdebug,
                 }
             }); 
 
@@ -160,30 +109,18 @@ sub _auto_load {
 
     }
 
+    my ($package, $filename, $line) = caller(2);
     $self->throw_msg(
         dotid($self->class) . '.auto_load.invmethod',
         'invmethod',
-        $name
+        $name, $filename, $line
     );
 
 }
 
-sub init {
+sub _create_methods {
     my $self = shift;
-
-    # load the messages
-    
-    $self->load_msgs();
-
-    # process PARAMS
-
-    my $class = $self->class;
-    my $params = $self->class->hash_vars('PARAMS');
-    my $p = $self->validate_params(\@_, $params, $class);
-
-    # build our object
-
-    $self->{config} = $p;
+    my $p = shift;
 
     no strict "refs";               # to register new methods in package
     no warnings;                    # turn off warnings
@@ -199,45 +136,31 @@ sub init {
 
     }
 
-    $self->debugging($self->xdebug);
-
-    return $self;
-
-}
-
-package # hide from PAUSE
-  XAS::Alerts;
-
-use XAS::Class
-  version => '0.01',
-  base    => 'XAS::Singleton',
-;
-
-sub check {
-    my $self = shift;
-
-    return $self->{enabled};
-
-}
-
-sub on {
-    my $self = shift;
-    my ($enable) = $self->validate_params(\@_, [ 
-        { optional => 1, default => undef, regex => qr/0|1/ } 
-    ]);
-
-    $self->{enabled} = $enable if (defined($enable));
-
-    return $self->{enabled};
-
 }
 
 sub init {
-    my $class = shift;
+    my $self = shift;
 
-    my $self = $class->SUPER::init(@_);
+    # load the environment
 
-    $self->{enabled} = 0;
+    $self->{env} = XAS::Factory->module('environment');
+    $XAS::Base::MESSAGES = $self->env->get_msgs();
+
+    # process PARAMS
+
+    my $class = $self->class;
+    my $params = $self->class->hash_vars('PARAMS');
+    my $p = $self->validate_params(\@_, $params, $class);
+
+    # build our object
+
+    $self->{config} = $p;
+    $self->_create_methods($p);
+
+    # set defaults
+
+    $self->env->alerts($self->alerts);
+    $self->env->xdebug($self->xdebug);
 
     return $self;
 
@@ -264,9 +187,9 @@ XAS::Base - The base class for the XAS environment
 =head1 DESCRIPTION
 
 This module defines a base class for the XAS Environment and inherits from
-L<Badger::Base|http://http://badgerpower.com/docs/Badger/Base.html>. The package variable $PARAMS is used to hold 
+L<Badger::Base|https://metacpan.org/pod/Badger::Base>. The package variable $PARAMS is used to hold 
 the parameters that this class uses for initialization. Due to the pseudo 
-inheritance of package variables provided by L<Badger::Class|http://badgerpower.com/docs/Badger/Class.html>, these 
+inheritance of package variables provided by L<Badger::Class|https://metacpan.org/pod/Badger::Class>, these 
 parameters can be changed or extended by inheriting classes. The parameters 
 are validated using L<Params::Validate|https://metacpan.org/pod/Params::Validate>. Any parameters defined in $PARAMS 
 auto-magically become accessors toward their values.
@@ -281,18 +204,6 @@ the validate_params() method.
 By default the parameter -xdebug is set to 0. This parameter is used to
 turn on debugging output.
 
-=head2 load_msgs
-
-This method loads the message files. It searches @INC for the XAS 
-installation. When found, it loads any message files found into the package 
-variable MESSAGES. A message file has the following format:
-
- [messages]
- exception = %s: %s
-
-Where "exception" is the name of the message and rest is the text that will
-be used for the message. 
-
 =head2 validate_params($params, $spec, $class)
 
 This method is used to validate parameters. Internally this uses 
@@ -315,7 +226,7 @@ An array ref to a set of parameters.
 
 =item B<$spec>
 
-A validation spec as defined by L<Params::Validate>.
+A validation spec as defined by L<Params::Validate|https://metacpan.org/pod/Params::Validate>.
 
 =item B<$class>
 
@@ -333,7 +244,7 @@ error message. It takes these parameters:
 
 =item B<$param>
 
-The error message returned by L<Params::Validate>.
+The error message returned by L<Params::Validate|https://metacpan.org/pod/Params::Validate>.
 
 =item B<$class>
 
@@ -382,10 +293,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+TThis is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
