@@ -1,13 +1,13 @@
 package XAS::Lib::Stomp::Frame;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use XAS::Class
   debug     => 0,
   version   => $VERSION,
   base      => 'XAS::Base',
   accessors => 'eol header',
-  mutators  => 'target command body',
+  mutators  => 'command body',
   constants => 'CRLF',
   codec     => 'unicode',
   constant => {
@@ -19,7 +19,6 @@ use XAS::Class
       -body    => { optional => 1, default => undef },
       -command => { optional => 1, default => undef },
       -headers => { optional => 1, default => undef },
-      -target  => { optional => 1, default => '1.0', regex => qr/(1\.0|1\.1|1\.2)/ },
     }
   }
 ;
@@ -61,7 +60,7 @@ sub as_string {
 
     }
 
-    if ($self->target > 1.1) {
+    if ($self->env->mqlevel > 1.1) {
 
         $frame = encode('utf8', $command) . $self->eol;
 
@@ -83,7 +82,7 @@ sub as_string {
 
     if (keys %{$headers}) {
 
-        $self->_encode_headers(\$headers) if ($self->target > 1.1);
+        $self->_encode_headers(\$headers) if ($self->env->mqlevel > 1.1);
 
         while (my ($key, $value) = each(%{$headers})) {
 
@@ -118,10 +117,11 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
     
-    $headers = $self->headers || {};
-    $self->{eol} = ($self->target > 1.1) ? CRLF : LF;
+    my $headers = $self->headers || {};
 
-    $self->_decode_headers(\$headers) if ($self->target > 1.1);
+    $self->{eol} = ($self->env->mqlevel > 1.1) ? CRLF : LF;
+
+    $self->_decode_headers(\$headers) if ($self->env->mqlevel > 1.1);
     $self->{header} = XAS::Lib::Stomp::Frame::Headers->new($headers);
 
     return $self;
@@ -162,8 +162,8 @@ sub _decode_headers {
             unless ($v =~ s/(\\.)/$DECODE_MAP{$1}/eg) {
 
                 $self->throw_msg(
-                    'xas.lib.stomp.frame.decode_header',
-                    'badval',
+                    'xas.lib.stomp.frame.decode_header.badval',
+                    'stomp_badval',
                 );
 
             }
@@ -175,8 +175,8 @@ sub _decode_headers {
             unless ($k =~ s/(\\.)/$DECODE_MAP{$1}/eg) {
 
                 $self->throw_msg(
-                    'xas.lib.stomp.frame.decode_header',
-                    'badkey'
+                    'xas.lib.stomp.frame.decode_header.badkey',
+                    'stomp_badkey'
                 );
 
             }
@@ -195,6 +195,7 @@ package # hide from cpan...
 our $VERSION = '0.01';
 
 use XAS::Class
+  debug     => 0,
   version   => $VERSION,
   base      => 'XAS::Base',
   constants => 'REFS',
@@ -305,7 +306,6 @@ XAS::Lib::Stomp::Frame - A STOMP Frame
   use XAS::Lib::Stomp::Frame;
 
   my $frame = XAS::Lib::Stomp::Frame->new(
-    -target  => '1.0',
     -command => $command,
     -headers => $headers,
     -body    => $body,
@@ -315,7 +315,6 @@ XAS::Lib::Stomp::Frame - A STOMP Frame
 
   my $frame = XAS:::Lib::Stomp::Frame->new();
 
-  $frame->target('1.0');
   $frame->command('MESSAGE');
   $frame->header->add('destination', '/queue/foo');
   $frame->body('this is the body');
@@ -350,11 +349,6 @@ It can take the following parameters:
 
 =over 4
 
-=item B<-target>
-
-Specify a STOMP protocol version number. It currently supports 1.0,
-1.1 and 1.2, defaulting to 1.0.
-
 =item B<-command>
 
 The command verb.
@@ -471,10 +465,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
